==> apgl-0.6.1.tar.gz: apgl-0.6.1/apgl/viroscopy/EdgePredictionExperiment.py <==

"""
The idea is to take the viroscopy graph and remove some edges and then make
some predictions for the missing edges.
"""

import logging
import sys
import numpy
from apgl.util import *
from apgl.graph import *
from apgl.predictors import *
from apgl.kernel import *
from apgl.data import * 
from apgl.viroscopy.HIVGraphReader import HIVGraphReader

logging.basicConfig(stream=sys.stdout, level=logging.INFO)

hivReader = HIVGraphReader()
graph = hivReader.readHIVGraph()

#The set of edges indexed by zeros is the contact graph
#The ones indexed by 1 is the infection graph
edgeTypeIndex1 = 0
edgeTypeIndex2 = 1
sGraphContact = graph.getSparseGraph(edgeTypeIndex1)
sGraphInfect = graph.getSparseGraph(edgeTypeIndex2)
sGraphContact = sGraphContact.union(sGraphInfect)

graph = sGraphContact

#First remove all isolate vertices
subgraphIds = [] 

for i in graph.getAllVertexIds():
    if graph.neighbours(i).shape[0] != 0:
        subgraphIds.append(i)

graph = graph.subgraph(subgraphIds)
logging.info("New graph size after removing isolated vertices: " + str(graph.getNumVertices()))

#Take a subgraph for test purposes
#perm = numpy.random.permutation(graph.getNumVertices())[0:1000]
#graph = graph.subgraph(perm)
#logging.info("Subgraph size : " + str(graph.getNumVertices()))

#Standardise the Vertices
standardiser = Standardiser()
V = graph.getVertexList().getVertices(range(graph.getNumVertices()))
V = standardiser.standardiseArray(V)
graph.getVertexList().setVertices(V)


numEdges = int(graph.getNumEdges())
folds = 5
windowSize = 100
foldSize = numpy.floor(numEdges/folds)

"""
Split the number of edges into groups, then train on one set and test on
the remaining.
"""

edges = graph.getAllEdges()
cvIndices = Sampling.crossValidation(folds, numEdges)
perm = numpy.random.permutation(numEdges)


#lmbda = 0.1
#learningAlg = RidgeRegression(lmbda)
learningAlg = LibSVM()
learningAlg.setSvmType("Epsilon_SVR")
fileName = PathDefaults.getOutputDir() + "viroscopy/ViroGaussianSVMParams"
learningAlg.loadParams(fileName)

paramsFileName = PathDefaults.getOutputDir() + "viroscopy/EgoEdgePredictorRBFParams.npz"
egoEdgePredParams = numpy.load(paramsFileName)

lmbda1 = egoEdgePredParams['arr_1'][0]
lmbda2 = egoEdgePredParams['arr_1'][1]
sigma = egoEdgePredParams['arr_1'][2]
kernel = GaussianKernel(sigma)
alterPredictor = PrimalRidgeRegression(lmbda1)
egoPredictor = KernelRidgeRegression(kernel)
egoEdgePredictor = EgoEdgePredictor(alterPredictor, egoPredictor, windowSize)

predictors = []
predictors.append(egoEdgePredictor)
predictors.append(VertexEdgePredictor(learningAlg, windowSize))
predictors.append(AdamicPredictor(windowSize))
predictors.append(JacardEdgePredictor(windowSize))
predictors.append(CommonNeighboursPredictor(windowSize))
predictors.append(PrefAttachPredictor(windowSize))
predictors.append(RandomEdgePredictor(windowSize))


numMethods = len(predictors)
errors = numpy.zeros((folds, numMethods))

for i in range(0, folds):
    print("Fold = " + str(i))
    trainIndices = perm[cvIndices[i][0]]
    testIndices = perm[cvIndices[i][1]]

    trainGraph = SparseGraph(graph.getVertexList())
    trainGraph.addEdges(edges[trainIndices, :])

    testEdges = edges[testIndices, :]

    P = numpy.zeros((testEdges.shape[0], windowSize, numMethods))

    for k in range(numMethods):
        predictors[k].learnModel(trainGraph)
        P[:,:, k], S = predictors[k].predictEdges(testEdges[:, 0])

        for j in range(testEdges.shape[0]):            
            if not testEdges[j, 1] in P[j,:, k]:
                errors[i, k] += float(1)/testEdges.shape[0]


print(errors)
print(numpy.mean(errors, 0))

errorFileName = PathDefaults.getOutputDir() + "viroscopy/EdgePredictionExpErrors"
numpy.savez(errorFileName, numpy.mean(errors, 0))

logging.info("Saved errors to file " + errorFileName)

==> apgl-0.6.5.tar.gz: apgl-0.6.5/apgl/viroscopy/EdgePredictionExperiment.py <==

"""
The idea is to take the viroscopy graph and remove some edges and then make
some predictions for the missing edges.
"""

import logging
import sys
import numpy
from apgl.util import *
from apgl.graph import *
from apgl.predictors import *
from apgl.kernel import *
from apgl.data import * 
from apgl.viroscopy.HIVGraphReader import HIVGraphReader

logging.basicConfig(stream=sys.stdout, level=logging.INFO)

hivReader = HIVGraphReader()
graph = hivReader.readHIVGraph()

#The set of edges indexed by zeros is the contact graph
#The ones indexed by 1 is the infection graph
edgeTypeIndex1 = 0
edgeTypeIndex2 = 1
sGraphContact = graph.getSparseGraph(edgeTypeIndex1)
sGraphInfect = graph.getSparseGraph(edgeTypeIndex2)
sGraphContact = sGraphContact.union(sGraphInfect)

graph = sGraphContact

#First remove all isolate vertices
subgraphIds = [] 

for i in graph.getAllVertexIds():
    if graph.neighbours(i).shape[0] != 0:
        subgraphIds.append(i)

graph = graph.subgraph(subgraphIds)
logging.info("New graph size after removing isolated vertices: " + str(graph.getNumVertices()))

#Take a subgraph for test purposes
#perm = numpy.random.permutation(graph.getNumVertices())[0:1000]
#graph = graph.subgraph(perm)
#logging.info("Subgraph size : " + str(graph.getNumVertices()))

#Standardise the Vertices
standardiser = Standardiser()
V = graph.getVertexList().getVertices(list(range(graph.getNumVertices())))
V = standardiser.standardiseArray(V)
graph.getVertexList().setVertices(V)


numEdges = int(graph.getNumEdges())
folds = 5
windowSize = 100
foldSize = numpy.floor(numEdges/folds)

"""
Split the number of edges into groups, then train on one set and test on
the remaining.
"""

edges = graph.getAllEdges()
cvIndices = Sampling.crossValidation(folds, numEdges)
perm = numpy.random.permutation(numEdges)


#lmbda = 0.1
#learningAlg = RidgeRegression(lmbda)
learningAlg = LibSVM()
learningAlg.setSvmType("Epsilon_SVR")
fileName = PathDefaults.getOutputDir() + "viroscopy/ViroGaussianSVMParams"
learningAlg.loadParams(fileName)

paramsFileName = PathDefaults.getOutputDir() + "viroscopy/EgoEdgePredictorRBFParams.npz"
egoEdgePredParams = numpy.load(paramsFileName)

lmbda1 = egoEdgePredParams['arr_1'][0]
lmbda2 = egoEdgePredParams['arr_1'][1]
sigma = egoEdgePredParams['arr_1'][2]
kernel = GaussianKernel(sigma)
alterPredictor = PrimalRidgeRegression(lmbda1)
egoPredictor = KernelRidgeRegression(kernel)
egoEdgePredictor = EgoEdgePredictor(alterPredictor, egoPredictor, windowSize)

predictors = []
predictors.append(egoEdgePredictor)
predictors.append(VertexEdgePredictor(learningAlg, windowSize))
predictors.append(AdamicPredictor(windowSize))
predictors.append(JacardEdgePredictor(windowSize))
predictors.append(CommonNeighboursPredictor(windowSize))
predictors.append(PrefAttachPredictor(windowSize))
predictors.append(RandomEdgePredictor(windowSize))


numMethods = len(predictors)
errors = numpy.zeros((folds, numMethods))

for i in range(0, folds):
    print(("Fold = " + str(i)))
    trainIndices = perm[cvIndices[i][0]]
    testIndices = perm[cvIndices[i][1]]

    trainGraph = SparseGraph(graph.getVertexList())
    trainGraph.addEdges(edges[trainIndices, :])

    testEdges = edges[testIndices, :]

    P = numpy.zeros((testEdges.shape[0], windowSize, numMethods))

    for k in range(numMethods):
        predictors[k].learnModel(trainGraph)
        P[:,:, k], S = predictors[k].predictEdges(testEdges[:, 0])

        for j in range(testEdges.shape[0]):            
            if not testEdges[j, 1] in P[j,:, k]:
                errors[i, k] += float(1)/testEdges.shape[0]


print(errors)
print((numpy.mean(errors, 0)))

errorFileName = PathDefaults.getOutputDir() + "viroscopy/EdgePredictionExpErrors"
numpy.savez(errorFileName, numpy.mean(errors, 0))

logging.info("Saved errors to file " + errorFileName)
